@@ -6,6 +6,6 @@
 #include<iterator>
 #include<Rcpp.h>
 
-RcppExport SEXP svmlight_writer(SEXP rfile_name, SEXP rdata, SEXP rlabels, SEXP rno_bias_term, SEXP ruse_r_metadata); 
+RcppExport SEXP svmlight_writer(SEXP rfile_name, SEXP rdata, SEXP rlabels); 
 
 #endif
